@@ -17,6 +17,7 @@
 #' @param shuffle Logical to control if the position of sounds is randomized. Having all sounds from the same treatment in a sequence can be problematic if an environmental noise masks them. Hence 'shuffle' is useful to avoid having sounds from the same treatment next to each other. Default is \code{FALSE}.
 #' @param hrm.freqs Numeric vector with the frequencies of the harmonics relative to the fundamental frequency. The default values are c(1/2, 1/3, 2/3, 1/4, 3/4, 1/5, 1/6, 1/7, 1/8, 1/9, 1/10).
 #' @param sampling.rate Numeric vector of length 1. Sets the sampling frequency of the wave object (in kHz). Default is 44.1.
+#' @param freq.range Numeric vector of length 1 with the frequency range around the simulated frequency in which signals will modulate. Default is 2 which means that sounds will range +/- 1 kHz around the target frequency.
 #' @return An extended selection table, which can be input into \code{\link{master_sound_file}} to create the .wav file. The table contains columns for each of the varying features a 'treatment' column (useful to tell the acoustic features of each sound) and a 'replicate' column indicating the replicates for each 'treatment'.
 #' @family prepare acoustic data
 #' @seealso \code{\link[warbleR]{simulate_songs}} from the package warbleR.
@@ -47,12 +48,11 @@
 #' )
 #' }
 #'
-#' @references {
+#' @references
 #' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
-#' }
+#'
 #' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
 
-
 synth_sounds <-
   function(replicates = 1,
            frequencies,
@@ -68,7 +68,8 @@ synth_sounds <-
            hrm.freqs = c(1 / 2, 1 / 3, 2 / 3, 1 / 4, 3 / 4, 1 / 5, 1 / 6, 1 / 7, 1 /
                            8, 1 / 9, 1 / 10),
            sampling.rate = 44.1,
-           pb = TRUE) {
+           pb = TRUE,
+           freq.range = 2) {
     # check arguments
     arguments <- as.list(base::match.call())
     
@@ -144,7 +145,8 @@ synth_sounds <-
         sig2 = sig2,
         seed = seed,
         hrm.freqs = hrm.freqs,
-        sampling.rate = sampling.rate
+        sampling.rate = sampling.rate,
+        fr = freq.range
       )
     
     # name with parameters
